# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.data_plane import DataPlane
from arthur_client.api_bindings.models.dataset_reference import DatasetReference
from arthur_client.api_bindings.models.model_metric_spec import ModelMetricSpec
from arthur_client.api_bindings.models.model_metrics_schedule import ModelMetricsSchedule
from arthur_client.api_bindings.models.model_problem_type import ModelProblemType
from arthur_client.api_bindings.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Model(BaseModel):
    """
    Model
    """ # noqa: E501
    created_at: datetime = Field(description="Time of record creation.")
    updated_at: datetime = Field(description="Time of last record update.")
    id: StrictStr = Field(description="ID of the model.")
    project_id: StrictStr = Field(description="ID of the parent project.")
    name: StrictStr = Field(description="Name of the model.")
    description: Optional[StrictStr]
    onboarding_identifier: Optional[StrictStr] = None
    last_updated_by_user: Optional[User] = None
    metric_config: ModelMetricSpec = Field(description="Metric configuration of the model.")
    schedule: Optional[ModelMetricsSchedule] = None
    model_problem_types: List[ModelProblemType] = Field(description="Unique model problem types of associated datasets.")
    datasets: List[DatasetReference] = Field(description="Datasets for the model.")
    data_plane_id: StrictStr = Field(description="ID of the data plane backing this model.")
    data_plane: DataPlane = Field(description="Data plane backing this model.")
    agent_id: Optional[StrictStr] = None
    project_name: StrictStr = Field(description="Name of the parent project.")
    __properties: ClassVar[List[str]] = ["created_at", "updated_at", "id", "project_id", "name", "description", "onboarding_identifier", "last_updated_by_user", "metric_config", "schedule", "model_problem_types", "datasets", "data_plane_id", "data_plane", "agent_id", "project_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Model from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of last_updated_by_user
        if self.last_updated_by_user:
            _dict['last_updated_by_user'] = self.last_updated_by_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metric_config
        if self.metric_config:
            _dict['metric_config'] = self.metric_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of schedule
        if self.schedule:
            _dict['schedule'] = self.schedule.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in datasets (list)
        _items = []
        if self.datasets:
            for _item_datasets in self.datasets:
                if _item_datasets:
                    _items.append(_item_datasets.to_dict())
            _dict['datasets'] = _items
        # override the default output from pydantic by calling `to_dict()` of data_plane
        if self.data_plane:
            _dict['data_plane'] = self.data_plane.to_dict()
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if onboarding_identifier (nullable) is None
        # and model_fields_set contains the field
        if self.onboarding_identifier is None and "onboarding_identifier" in self.model_fields_set:
            _dict['onboarding_identifier'] = None

        # set to None if last_updated_by_user (nullable) is None
        # and model_fields_set contains the field
        if self.last_updated_by_user is None and "last_updated_by_user" in self.model_fields_set:
            _dict['last_updated_by_user'] = None

        # set to None if schedule (nullable) is None
        # and model_fields_set contains the field
        if self.schedule is None and "schedule" in self.model_fields_set:
            _dict['schedule'] = None

        # set to None if agent_id (nullable) is None
        # and model_fields_set contains the field
        if self.agent_id is None and "agent_id" in self.model_fields_set:
            _dict['agent_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Model from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "id": obj.get("id"),
            "project_id": obj.get("project_id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "onboarding_identifier": obj.get("onboarding_identifier"),
            "last_updated_by_user": User.from_dict(obj["last_updated_by_user"]) if obj.get("last_updated_by_user") is not None else None,
            "metric_config": ModelMetricSpec.from_dict(obj["metric_config"]) if obj.get("metric_config") is not None else None,
            "schedule": ModelMetricsSchedule.from_dict(obj["schedule"]) if obj.get("schedule") is not None else None,
            "model_problem_types": obj.get("model_problem_types"),
            "datasets": [DatasetReference.from_dict(_item) for _item in obj["datasets"]] if obj.get("datasets") is not None else None,
            "data_plane_id": obj.get("data_plane_id"),
            "data_plane": DataPlane.from_dict(obj["data_plane"]) if obj.get("data_plane") is not None else None,
            "agent_id": obj.get("agent_id"),
            "project_name": obj.get("project_name")
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.agent_metadata import AgentMetadata
from arthur_client.api_bindings.models.new_metric_request import NewMetricRequest
from arthur_client.api_bindings.models.new_rule_request import NewRuleRequest
from arthur_client.api_bindings.models.task_type import TaskType
from typing import Optional, Set
from typing_extensions import Self

class CreateModelTaskJobSpec(BaseModel):
    """
    CreateModelTaskJobSpec
    """ # noqa: E501
    job_type: Optional[StrictStr] = 'create_model_task'
    connector_id: StrictStr = Field(description="The id of the engine internal connector to use to create the task.")
    task_name: StrictStr = Field(description="The name of the task.")
    onboarding_identifier: Optional[StrictStr] = None
    initial_rules: List[NewRuleRequest] = Field(description="The initial rules to apply to the created model.")
    task_type: Optional[TaskType] = Field(default=None, description="The type of task to create.")
    initial_metrics: List[NewMetricRequest] = Field(description="The initial metrics to apply to agentic tasks.")
    agent_metadata: Optional[AgentMetadata] = None
    __properties: ClassVar[List[str]] = ["job_type", "connector_id", "task_name", "onboarding_identifier", "initial_rules", "task_type", "initial_metrics", "agent_metadata"]

    @field_validator('job_type')
    def job_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['create_model_task']):
            raise ValueError("must be one of enum values ('create_model_task')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateModelTaskJobSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in initial_rules (list)
        _items = []
        if self.initial_rules:
            for _item_initial_rules in self.initial_rules:
                if _item_initial_rules:
                    _items.append(_item_initial_rules.to_dict())
            _dict['initial_rules'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in initial_metrics (list)
        _items = []
        if self.initial_metrics:
            for _item_initial_metrics in self.initial_metrics:
                if _item_initial_metrics:
                    _items.append(_item_initial_metrics.to_dict())
            _dict['initial_metrics'] = _items
        # override the default output from pydantic by calling `to_dict()` of agent_metadata
        if self.agent_metadata:
            _dict['agent_metadata'] = self.agent_metadata.to_dict()
        # set to None if onboarding_identifier (nullable) is None
        # and model_fields_set contains the field
        if self.onboarding_identifier is None and "onboarding_identifier" in self.model_fields_set:
            _dict['onboarding_identifier'] = None

        # set to None if agent_metadata (nullable) is None
        # and model_fields_set contains the field
        if self.agent_metadata is None and "agent_metadata" in self.model_fields_set:
            _dict['agent_metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateModelTaskJobSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "job_type": obj.get("job_type") if obj.get("job_type") is not None else 'create_model_task',
            "connector_id": obj.get("connector_id"),
            "task_name": obj.get("task_name"),
            "onboarding_identifier": obj.get("onboarding_identifier"),
            "initial_rules": [NewRuleRequest.from_dict(_item) for _item in obj["initial_rules"]] if obj.get("initial_rules") is not None else None,
            "task_type": obj.get("task_type"),
            "initial_metrics": [NewMetricRequest.from_dict(_item) for _item in obj["initial_metrics"]] if obj.get("initial_metrics") is not None else None,
            "agent_metadata": AgentMetadata.from_dict(obj["agent_metadata"]) if obj.get("agent_metadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.agents_v1_api import AgentsV1Api


class TestAgentsV1Api(unittest.TestCase):
    """AgentsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_registered_agent_by_id(self) -> None:
        """Test case for get_registered_agent_by_id

        Get A Registered Agent By Its Id.
        """
        pass

    def test_list_agents_for_workspace(self) -> None:
        """Test case for list_agents_for_workspace

        List All Agents For A Workspace.
        """
        pass

    def test_list_data_sources_for_workspace(self) -> None:
        """Test case for list_data_sources_for_workspace

        List All Registered Agent Data Sources For A Workspace.
        """
        pass

    def test_list_llm_models_for_workspace(self) -> None:
        """Test case for list_llm_models_for_workspace

        List All Registered Agent Llm Models For A Workspace.
        """
        pass

    def test_list_sub_agents_for_workspace(self) -> None:
        """Test case for list_sub_agents_for_workspace

        List All Registered Agent Sub-Agents For A Workspace.
        """
        pass

    def test_list_tools_for_workspace(self) -> None:
        """Test case for list_tools_for_workspace

        List All Registered Agent Tools For A Workspace.
        """
        pass

    def test_list_unregistered_agents_for_workspace(self) -> None:
        """Test case for list_unregistered_agents_for_workspace

        List All Unregistered Agents For A Workspace.
        """
        pass

    def test_put_agents(self) -> None:
        """Test case for put_agents

        Upsert Agents.
        """
        pass

    def test_update_unregistered_agent(self) -> None:
        """Test case for update_unregistered_agent

        Update An Unregistered Agent.
        """
        pass


if __name__ == '__main__':
    unittest.main()



from .device_authorizer import DeviceAuthorizer
from .discovery import ArthurOIDCMetadata
from .oauth_api_config import ArthurOAuthSessionAPIConfiguration
from .session import ArthurClientCredentialsAPISession



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.model import Model

class TestModel(unittest.TestCase):
    """Model unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Model:
        """Test Model
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Model`
        """
        model = Model()
        if include_optional:
            return Model(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                project_id = '',
                name = '',
                description = '',
                onboarding_identifier = '',
                last_updated_by_user = arthur_client.api_bindings.models.user.User(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    organization_id = '', 
                    id = '', 
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    picture = '', 
                    user_type = 'user', 
                    data_plane_id = '', 
                    client_id = '', 
                    organization_name = '', ),
                metric_config = arthur_client.api_bindings.models.model_metric_spec.ModelMetricSpec(
                    aggregation_specs = [
                        arthur_client.api_bindings.models.aggregation_spec.AggregationSpec(
                            aggregation_id = '', 
                            aggregation_init_args = [
                                arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                    arg_key = '', 
                                    arg_value = null, )
                                ], 
                            aggregation_args = [
                                arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                    arg_key = '', 
                                    arg_value = null, )
                                ], 
                            aggregation_kind = 'default', 
                            aggregation_version = 56, )
                        ], 
                    id = '', ),
                schedule = arthur_client.api_bindings.models.model_metrics_schedule.ModelMetricsSchedule(
                    cron = '', 
                    lookback_period_seconds = 56, 
                    name = '', 
                    id = '', ),
                model_problem_types = [
                    'regression'
                    ],
                datasets = [
                    arthur_client.api_bindings.models.dataset_reference.DatasetReference(
                        dataset_id = '', 
                        dataset_name = '', 
                        dataset_connector_type = 'shield', )
                    ],
                data_plane_id = '',
                data_plane = arthur_client.api_bindings.models.data_plane.DataPlane(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    name = '', 
                    workspace_id = '', 
                    description = '', 
                    user_id = '', 
                    infrastructure = 'AWS', 
                    last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                        gen_ai_enabled = True, ), ),
                agent_id = '',
                project_name = ''
            )
        else:
            return Model(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                project_id = '',
                name = '',
                description = '',
                metric_config = arthur_client.api_bindings.models.model_metric_spec.ModelMetricSpec(
                    aggregation_specs = [
                        arthur_client.api_bindings.models.aggregation_spec.AggregationSpec(
                            aggregation_id = '', 
                            aggregation_init_args = [
                                arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                    arg_key = '', 
                                    arg_value = null, )
                                ], 
                            aggregation_args = [
                                arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                    arg_key = '', 
                                    arg_value = null, )
                                ], 
                            aggregation_kind = 'default', 
                            aggregation_version = 56, )
                        ], 
                    id = '', ),
                model_problem_types = [
                    'regression'
                    ],
                datasets = [
                    arthur_client.api_bindings.models.dataset_reference.DatasetReference(
                        dataset_id = '', 
                        dataset_name = '', 
                        dataset_connector_type = 'shield', )
                    ],
                data_plane_id = '',
                data_plane = arthur_client.api_bindings.models.data_plane.DataPlane(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    name = '', 
                    workspace_id = '', 
                    description = '', 
                    user_id = '', 
                    infrastructure = 'AWS', 
                    last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                        gen_ai_enabled = True, ), ),
                project_name = '',
        )
        """

    def testModel(self):
        """Test Model"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_policy import ResourceListPolicy

class TestResourceListPolicy(unittest.TestCase):
    """ResourceListPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListPolicy:
        """Test ResourceListPolicy
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListPolicy`
        """
        model = ResourceListPolicy()
        if include_optional:
            return ResourceListPolicy(
                records = [
                    arthur_client.api_bindings.models.policy.Policy(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        organization_id = '', 
                        name = '', 
                        description = '', 
                        owner_group_id = '', 
                        webhook_id = '', 
                        enforcement_delay_days = 56, 
                        alert_rules = [
                            arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                threshold = 1.337, 
                                bound = 'upper_bound', 
                                query = '', 
                                metric_name = '', )
                            ], 
                        attestation_rules = [
                            arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                validity_period_days = 56, )
                            ], 
                        last_updated_by_user_id = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListPolicy(
                records = [
                    arthur_client.api_bindings.models.policy.Policy(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        organization_id = '', 
                        name = '', 
                        description = '', 
                        owner_group_id = '', 
                        webhook_id = '', 
                        enforcement_delay_days = 56, 
                        alert_rules = [
                            arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                threshold = 1.337, 
                                bound = 'upper_bound', 
                                query = '', 
                                metric_name = '', )
                            ], 
                        attestation_rules = [
                            arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                validity_period_days = 56, )
                            ], 
                        last_updated_by_user_id = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListPolicy(self):
        """Test ResourceListPolicy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_model import ResourceListModel

class TestResourceListModel(unittest.TestCase):
    """ResourceListModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListModel:
        """Test ResourceListModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListModel`
        """
        model = ResourceListModel()
        if include_optional:
            return ResourceListModel(
                records = [
                    arthur_client.api_bindings.models.model.Model(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        project_id = '', 
                        name = '', 
                        description = '', 
                        onboarding_identifier = '', 
                        last_updated_by_user = arthur_client.api_bindings.models.user.User(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            organization_id = '', 
                            id = '', 
                            first_name = '', 
                            last_name = '', 
                            email = '', 
                            picture = '', 
                            user_type = 'user', 
                            data_plane_id = '', 
                            client_id = '', 
                            organization_name = '', ), 
                        metric_config = arthur_client.api_bindings.models.model_metric_spec.ModelMetricSpec(
                            aggregation_specs = [
                                arthur_client.api_bindings.models.aggregation_spec.AggregationSpec(
                                    aggregation_id = '', 
                                    aggregation_init_args = [
                                        arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                            arg_key = '', 
                                            arg_value = null, )
                                        ], 
                                    aggregation_args = [
                                        arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                            arg_key = '', 
                                            arg_value = null, )
                                        ], 
                                    aggregation_kind = 'default', 
                                    aggregation_version = 56, )
                                ], 
                            id = '', ), 
                        schedule = arthur_client.api_bindings.models.model_metrics_schedule.ModelMetricsSchedule(
                            cron = '', 
                            lookback_period_seconds = 56, 
                            name = '', 
                            id = '', ), 
                        model_problem_types = [
                            'regression'
                            ], 
                        datasets = [
                            arthur_client.api_bindings.models.dataset_reference.DatasetReference(
                                dataset_id = '', 
                                dataset_name = '', 
                                dataset_connector_type = 'shield', )
                            ], 
                        data_plane_id = '', 
                        data_plane = arthur_client.api_bindings.models.data_plane.DataPlane(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            name = '', 
                            workspace_id = '', 
                            description = '', 
                            user_id = '', 
                            infrastructure = 'AWS', 
                            last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                                gen_ai_enabled = True, ), ), 
                        agent_id = '', 
                        project_name = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListModel(
                records = [
                    arthur_client.api_bindings.models.model.Model(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        project_id = '', 
                        name = '', 
                        description = '', 
                        onboarding_identifier = '', 
                        last_updated_by_user = arthur_client.api_bindings.models.user.User(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            organization_id = '', 
                            id = '', 
                            first_name = '', 
                            last_name = '', 
                            email = '', 
                            picture = '', 
                            user_type = 'user', 
                            data_plane_id = '', 
                            client_id = '', 
                            organization_name = '', ), 
                        metric_config = arthur_client.api_bindings.models.model_metric_spec.ModelMetricSpec(
                            aggregation_specs = [
                                arthur_client.api_bindings.models.aggregation_spec.AggregationSpec(
                                    aggregation_id = '', 
                                    aggregation_init_args = [
                                        arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                            arg_key = '', 
                                            arg_value = null, )
                                        ], 
                                    aggregation_args = [
                                        arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                                            arg_key = '', 
                                            arg_value = null, )
                                        ], 
                                    aggregation_kind = 'default', 
                                    aggregation_version = 56, )
                                ], 
                            id = '', ), 
                        schedule = arthur_client.api_bindings.models.model_metrics_schedule.ModelMetricsSchedule(
                            cron = '', 
                            lookback_period_seconds = 56, 
                            name = '', 
                            id = '', ), 
                        model_problem_types = [
                            'regression'
                            ], 
                        datasets = [
                            arthur_client.api_bindings.models.dataset_reference.DatasetReference(
                                dataset_id = '', 
                                dataset_name = '', 
                                dataset_connector_type = 'shield', )
                            ], 
                        data_plane_id = '', 
                        data_plane = arthur_client.api_bindings.models.data_plane.DataPlane(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = '', 
                            name = '', 
                            workspace_id = '', 
                            description = '', 
                            user_id = '', 
                            infrastructure = 'AWS', 
                            last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                                gen_ai_enabled = True, ), ), 
                        agent_id = '', 
                        project_name = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListModel(self):
        """Test ResourceListModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.policy import Policy

class TestPolicy(unittest.TestCase):
    """Policy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Policy:
        """Test Policy
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Policy`
        """
        model = Policy()
        if include_optional:
            return Policy(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                organization_id = '',
                name = '',
                description = '',
                owner_group_id = '',
                webhook_id = '',
                enforcement_delay_days = 56,
                alert_rules = [
                    arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy_id = '', 
                        name = '', 
                        description = '', 
                        threshold = 1.337, 
                        bound = 'upper_bound', 
                        query = '', 
                        metric_name = '', )
                    ],
                attestation_rules = [
                    arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy_id = '', 
                        name = '', 
                        description = '', 
                        validity_period_days = 56, )
                    ],
                last_updated_by_user_id = ''
            )
        else:
            return Policy(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                organization_id = '',
                name = '',
                owner_group_id = '',
                webhook_id = '',
                enforcement_delay_days = 56,
                alert_rules = [
                    arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy_id = '', 
                        name = '', 
                        description = '', 
                        threshold = 1.337, 
                        bound = 'upper_bound', 
                        query = '', 
                        metric_name = '', )
                    ],
                attestation_rules = [
                    arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        policy_id = '', 
                        name = '', 
                        description = '', 
                        validity_period_days = 56, )
                    ],
        )
        """

    def testPolicy(self):
        """Test Policy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.policies_v1_api import PoliciesV1Api


class TestPoliciesV1Api(unittest.TestCase):
    """PoliciesV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesV1Api()

    def tearDown(self) -> None:
        pass

    def test_check_assignment_compliance(self) -> None:
        """Test case for check_assignment_compliance

        Check Assignment Compliance
        """
        pass

    def test_check_model_compliance(self) -> None:
        """Test case for check_model_compliance

        Check Model Compliance
        """
        pass

    def test_check_policy_compliance(self) -> None:
        """Test case for check_policy_compliance

        Check Policy Compliance
        """
        pass

    def test_create_attestation(self) -> None:
        """Test case for create_attestation

        Create Attestation
        """
        pass

    def test_create_policy(self) -> None:
        """Test case for create_policy

        Create Policy
        """
        pass

    def test_create_policy_alert_rule(self) -> None:
        """Test case for create_policy_alert_rule

        Create Policy Alert Rule
        """
        pass

    def test_create_policy_assignments(self) -> None:
        """Test case for create_policy_assignments

        Create Policy Assignments
        """
        pass

    def test_create_policy_attestation_rule(self) -> None:
        """Test case for create_policy_attestation_rule

        Create Policy Attestation Rule
        """
        pass

    def test_delete_policy(self) -> None:
        """Test case for delete_policy

        Delete Policy
        """
        pass

    def test_delete_policy_alert_rule(self) -> None:
        """Test case for delete_policy_alert_rule

        Delete Policy Alert Rule
        """
        pass

    def test_delete_policy_assignment(self) -> None:
        """Test case for delete_policy_assignment

        Delete Policy Assignment
        """
        pass

    def test_delete_policy_attestation_rule(self) -> None:
        """Test case for delete_policy_attestation_rule

        Delete Policy Attestation Rule
        """
        pass

    def test_get_policy(self) -> None:
        """Test case for get_policy

        Get Policy
        """
        pass

    def test_get_policy_alert_rule(self) -> None:
        """Test case for get_policy_alert_rule

        Get Policy Alert Rule
        """
        pass

    def test_get_policy_assignment(self) -> None:
        """Test case for get_policy_assignment

        Get Policy Assignment
        """
        pass

    def test_get_policy_attestation_rule(self) -> None:
        """Test case for get_policy_attestation_rule

        Get Policy Attestation Rule
        """
        pass

    def test_list_assignment_attestations(self) -> None:
        """Test case for list_assignment_attestations

        List Assignment Attestations
        """
        pass

    def test_list_model_attestations(self) -> None:
        """Test case for list_model_attestations

        List Model Attestations
        """
        pass

    def test_list_model_policy_assignments(self) -> None:
        """Test case for list_model_policy_assignments

        List Model Policy Assignments
        """
        pass

    def test_list_policies(self) -> None:
        """Test case for list_policies

        List Policies
        """
        pass

    def test_list_policy_alert_rules(self) -> None:
        """Test case for list_policy_alert_rules

        List Policy Alert Rules
        """
        pass

    def test_list_policy_assignments(self) -> None:
        """Test case for list_policy_assignments

        List Policy Assignments
        """
        pass

    def test_list_policy_attestation_rules(self) -> None:
        """Test case for list_policy_attestation_rules

        List Policy Attestation Rules
        """
        pass

    def test_list_workspace_policy_assignments(self) -> None:
        """Test case for list_workspace_policy_assignments

        List Workspace Policy Assignments
        """
        pass

    def test_set_compliance_status(self) -> None:
        """Test case for set_compliance_status

        Set Compliance Status
        """
        pass

    def test_update_policy(self) -> None:
        """Test case for update_policy

        Update Policy
        """
        pass

    def test_update_policy_alert_rule(self) -> None:
        """Test case for update_policy_alert_rule

        Update Policy Alert Rule
        """
        pass

    def test_update_policy_attestation_rule(self) -> None:
        """Test case for update_policy_attestation_rule

        Update Policy Attestation Rule
        """
        pass


if __name__ == '__main__':
    unittest.main()
